Django REST Search
==================

Django REST Search provides a set of classes to facilitate the integration of
ElasticSearch into applications powered by the Django REST Framework.

Full documentation for the project is available at
http://django-rest-search.readthedocs.io/.
